@@ -1,7 +1,9 @@
-use serde::{Deserialize, Serialize};
+use chrono::{DateTime, Duration, Local, NaiveDate, NaiveDateTime, Utc};
 use std::collections::HashMap;
 
-#[derive(Debug, Clone, Serialize, Deserialize, PartialEq)]
+use super::{Period, Timestamp};
+
+#[derive(Debug, Clone, PartialEq)]
 pub enum Value {
     Null,
     Bool(bool),
@@ -12,6 +14,11 @@ pub enum Value {
     Float(f32),
     Double(f64),
     String(String),
+    Date(NaiveDate),
+    DateTime(NaiveDateTime),
+    Duration(Duration),
+    LocalTime(DateTime<Local>),
+    UtcTime(DateTime<Utc>),
     UnsignedBytes(Vec<u8>),
     Array(Vec<Value>),
     Attributes(HashMap<String, Value>),
@@ -53,6 +60,58 @@ impl From<String> for Value {
     }
 }
 
+impl From<NaiveDate> for Value {
+    fn from(v: NaiveDate) -> Self {
+        Value::Date(v)
+    }
+}
+
+impl From<NaiveDateTime> for Value {
+    fn from(v: NaiveDateTime) -> Self {
+        Value::DateTime(v)
+    }
+}
+
+impl From<Duration> for Value {
+    fn from(v: Duration) -> Self {
+        Value::Duration(v)
+    }
+}
+
+impl From<Period> for Value {
+    fn from(v: Period) -> Self {
+        let v = match v {
+            Period::Days(v) => Duration::days(v),
+            Period::Hours(v) => Duration::hours(v),
+            Period::Minutes(v) => Duration::minutes(v),
+            Period::Secs(v) => Duration::seconds(v),
+            Period::Millis(v) => Duration::milliseconds(v),
+        };
+        Value::Duration(v)
+    }
+}
+
+impl From<DateTime<Local>> for Value {
+    fn from(v: DateTime<Local>) -> Self {
+        Value::LocalTime(v)
+    }
+}
+
+impl From<DateTime<Utc>> for Value {
+    fn from(v: DateTime<Utc>) -> Self {
+        Value::UtcTime(v)
+    }
+}
+
+impl From<Timestamp> for Value {
+    fn from(v: Timestamp) -> Self {
+        match v {
+            Timestamp::Millis(v) => Value::Duration(Duration::milliseconds(v as i64)),
+            Timestamp::Secs(v) => Value::Duration(Duration::seconds(v as i64)),
+        }
+    }
+}
+
 impl From<Vec<u8>> for Value {
     fn from(v: Vec<u8>) -> Self {
         Value::UnsignedBytes(v)
